@@ -1,47 +1,27 @@
 /********************************************************************\
 
-  Name:         elogd.c
+  Name:         elconv.c
   Created by:   Stefan Ritt
+  Copyright 2000 + Stefan Ritt
+
+  ELOG is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
+
+  ELOG is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with ELOG.  If not, see <http://www.gnu.org/licenses/>.
+
+
 
   Contents:     Conversion program for ELOG messages
 
-  $Log: elconv.c,v $
-  Revision 1.8  2004/11/21 16:51:42  midas
-  Added debug print of dir
-
-  Revision 1.7  2004/09/18 04:42:46  midas
-  Fixed bug with not displaying inline images
-
-  Revision 1.6  2004/07/28 18:51:57  midas
-  Fixed error with gcc 3.4, thanks to Recai Oktas
-
-  Revision 1.5  2004/04/15 06:48:43  midas
-  Fixed bug with unterminated string
-
-  Revision 1.4  2004/02/17 11:19:49  midas
-  Fixed compiler warnings
-
-  Revision 1.3  2004/01/07 11:14:53  midas
-  Changed line length
-
-  Revision 1.2  2004/01/06 13:21:34  midas
-  Changed indent style
-
-  Revision 1.1  2003/01/30 14:45:07  midas
-  Moved files to src/ subdirectory
-
-  Revision 1.4  2002/06/07 10:00:26  midas
-  Added some non-verbose messages
-
-  Revision 1.3  2002/06/07 09:30:37  midas
-  Fixed thread_list re-allocation
-
-  Revision 1.2  2002/06/03 12:37:54  midas
-  Added thread evaluation
-
-  Revision 1.1  2002/05/29 10:22:46  midas
-  Initial revision
-
+  $Id$
 
 \********************************************************************/
 
@@ -179,10 +159,9 @@ void el_decode(char *message, char *key, char *result)
 
 int fnmatch1(const char *pattern, const char *string)
 {
-   const char *stringstart;
    char c, test;
 
-   for (stringstart = string;;)
+   for (;;)
       switch (c = *pattern++) {
       case EOS:
          return (*string == EOS ? 0 : 1);
@@ -296,7 +275,7 @@ INT ss_file_find(char *path, char *pattern, char **plist)
 
 INT el_search_message(char *tag, int *fh, BOOL walk, BOOL first)
 {
-   int lfh, i, n, d, min, max, size, offset, direction, last, status, did_walk;
+   int lfh, i, n, d, min, max, size, offset, direction, status, did_walk;
    struct tm *tms, ltms;
    time_t lt, ltime, lact;
    char str[256], file_name[256], dir[256];
@@ -505,8 +484,6 @@ INT el_search_message(char *tag, int *fh, BOOL walk, BOOL first)
       /* seek next message */
 
       /* read current message size */
-      last = TELL(lfh);
-
       i = read(lfh, str, 15);
       if (i <= 0) {
          close(lfh);
@@ -870,7 +847,7 @@ INT el_get_v1(char *tag, char *message, int *bufsize)
 
 \********************************************************************/
 {
-   int i, size, fh, offset, search_status;
+   int i, size, fh, search_status;
    char str[256];
 
    if (tag[0]) {
@@ -886,7 +863,6 @@ INT el_get_v1(char *tag, char *message, int *bufsize)
    }
 
    /* extract message size */
-   offset = TELL(fh);
    i = read(fh, str, 16);
    if (i <= 0) {
       close(fh);
@@ -901,7 +877,7 @@ INT el_get_v1(char *tag, char *message, int *bufsize)
    }
 
    /* read message */
-   memset(message, 0, sizeof(message));
+   memset(message, 0, *bufsize);
    read(fh, message, size);
    close(fh);
 
